@@ -1,8 +1,9 @@
 import click
 
-from cli.utils import Spotify
-from cli.utils.exceptions import *
-from cli.utils.functions import format_duration_ms
+from ..utils import Spotify
+from ..utils.parsers import *
+from ..utils.functions import format_duration_ms
+from ..utils.exceptions import *
 
 
 @click.command(options_metavar='[<options>]')
@@ -17,6 +18,9 @@ from cli.utils.functions import format_duration_ms
 def status(verbose=0, raw=False, _override={}, _return_parsed=False):
     """Describe the current playback session."""
     res = Spotify.request('me/player', method='GET')
+    if not res:
+        raise NoPlaybackError
+
     if raw:
         if verbose >= 0:
             import json
@@ -24,9 +28,6 @@ def status(verbose=0, raw=False, _override={}, _return_parsed=False):
 
         return res
 
-    if not res:
-        raise NoPlaybackError
-
     # raw
     data = {}
     data['is_podcast'] = res['currently_playing_type'] == 'episode'
@@ -42,41 +43,16 @@ def status(verbose=0, raw=False, _override={}, _return_parsed=False):
         'volume': res['device']['volume_percent'],
     }
     item = res['item']
-    context = {'type': None}
-    if res['context']:
-        context = {
-            'type': res['context']['type'],
-            'id': res['context']['href'].split('/')[-1],
-            'url': res['context']['external_urls']['spotify'],
-            'api': res['context']['href'],
-        }
+    context = parse_context(res['context'])
 
     data['music'] = {
-        # note: playback context not available if private session or unnamed playlist
         'context': context,
-        'track': {
-            'name': item['name'],
-            'id': item['id'],
-            'url': item['external_urls']['spotify'],
-            'api': item['href'],
-            'track_number': item['track_number'],
-            'progress': format_duration_ms(res['progress_ms']),
-            'duration': format_duration_ms(item['duration_ms']),
-        },
-        'album': {
-            'name': item['album']['name'],
-            'id': item['album']['id'],
-            'url': item['album']['external_urls']['spotify'],
-            'api': item['album']['href'],
-            'release_date': item['album']['release_date'],
-        },
-        'artist': {
-            'names': [artist['name'] for artist in item['artists']],
-            'ids': [artist['id'] for artist in item['artists']],
-            'urls': [artist['external_urls']['spotify'] for artist in item['artists']],
-        },
+        'track': parse_track(item),
+        'album': parse_album(item['album']),
+        'artist': parse_artists(item['artists']),
     }
     music = data['music']
+    music['track']['progress'] = format_duration_ms(res['progress_ms'])
 
     # parsed
     if _override:
@@ -87,7 +63,9 @@ def status(verbose=0, raw=False, _override={}, _return_parsed=False):
         music['artist'][key] = music['artist'][key + 's'][0]
         music['artist']['long_' + key] = ', '.join(music['artist'][key + 's'])
         if key != 'name':
-            music['artist']['long_' + key] = music['artist']['long_' + key].replace(' ','')
+            music['artist']['long_' + key] = (
+                music['artist']['long_' + key].replace(' ', '')
+            )
 
     playback_status = 'Playing' if data['is_playing'] else 'Paused'
     playback_options = []
@@ -146,7 +124,7 @@ def status(verbose=0, raw=False, _override={}, _return_parsed=False):
         click.echo(
             '\n'
             'Device  {} ({})\n'
-            'URL:    {}'
+            'URL     {}'
             .format(
                 data['device']['name'],
                 data['device']['type'],
@@ -154,5 +132,4 @@ def status(verbose=0, raw=False, _override={}, _return_parsed=False):
             )
         )
 
-
     return
